Documentation
¶
Overview ¶
Package module is here to define any struct necessary to build a plugin compatible with Perses. The definition of a plugin is different to the one you can find in the dashboard definition. The plugin definition in the dashboard is more about the configuration of a plugin, while the one in the module is more about the definition of a plugin. The module definition is stricter and is used to validate the plugin before it is loaded into Perses.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Module ¶
type Module struct {
Metadata *Metadata `json:"metadata,omitempty" yaml:"metadata,omitempty"`
SchemasPath string `json:"schemasPath" yaml:"schemasPath"`
// ModuleName is deprecated and will be removed in the future. It is recommended to use the Metadata.Name field instead.
ModuleName string `json:"moduleName,omitempty" yaml:"moduleName,omitempty"`
// ModuleOrg is deprecated and will be removed in the future. It is recommended to use the Metadata.Registry field instead.
ModuleOrg string `json:"moduleOrg,omitempty" yaml:"moduleOrg,omitempty"`
Plugins []Plugin `json:"plugins" yaml:"plugins"`
}
func (*Module) UnmarshalJSON ¶
type Plugin ¶
type Plugin struct {
Kind plugin.Kind `json:"kind" yaml:"kind"`
Spec PluginSpec `json:"spec" yaml:"spec"`
}
func (*Plugin) UnmarshalJSON ¶
type PluginSpec ¶
Click to show internal directories.
Click to hide internal directories.